=========
Changelog
=========

Version 0.1
===========

- Project scaffolding added.
- Initial set of command-line scripts added.
- Author information added

Version 0.1.1
=============

- Entry points for expected command-line scripts added.
- Github Actions workflows for CI added.
- Refactored to be conda-friendly.

Version 0.1.4
=============

- Index optimization script with entry point now available.
- Test suites for diffraction geometry and Laue object libraries.
